Class: Binda::Image::ImageUploader

Inherits:
CarrierWave::Uploader::Base
  • Object
show all
Includes:
CarrierWave::MiniMagick
Defined in:
app/uploaders/binda/image/image_uploader.rb

Instance Method Summary collapse

Instance Method Details

#cache_dirObject



19
20
21
# File 'app/uploaders/binda/image/image_uploader.rb', line 19

def cache_dir
  "#{Rails.root}/tmp/uploads"
end

#content_type_whitelistObject

Add a white list of extensions which are allowed to be uploaded. For images you might use something like this: def extension_whitelist %w(jpg jpeg gif png) end



57
58
59
# File 'app/uploaders/binda/image/image_uploader.rb', line 57

def content_type_whitelist
  /image\//
end

#store_dirObject

Override the directory where uploaded files will be stored. This is a sensible default for uploaders that are meant to be mounted:



14
15
16
# File 'app/uploaders/binda/image/image_uploader.rb', line 14

def store_dir
  "uploads/#{model.class.to_s.underscore}/#{mounted_as}/#{model.id}"
end