Class: Binda::Video::VideoUploader
- Inherits:
-
CarrierWave::Uploader::Base
- Object
- CarrierWave::Uploader::Base
- Binda::Video::VideoUploader
- Defined in:
- app/uploaders/binda/video/video_uploader.rb
Instance Method Summary collapse
-
#extension_whitelist ⇒ Object
Add a white list of extensions which are allowed to be uploaded.
-
#store_dir ⇒ Object
Override the directory where uploaded files will be stored.
Instance Method Details
#extension_whitelist ⇒ Object
Add a white list of extensions which are allowed to be uploaded. For images you might use something like this:
40 41 42 |
# File 'app/uploaders/binda/video/video_uploader.rb', line 40 def extension_whitelist %w(mp4 webm ogg) end |
#store_dir ⇒ Object
Override the directory where uploaded files will be stored. This is a sensible default for uploaders that are meant to be mounted:
14 15 16 |
# File 'app/uploaders/binda/video/video_uploader.rb', line 14 def store_dir "uploads/#{model.class.to_s.underscore}/#{mounted_as}/#{model.id}" end |